package tools

import (
	"errors"
	"sync"

	"xbus.io/go-xbus/v3/api"
	"xbus.io/go-xbus/v3/api/control"
)

// ErrNoSuchActor is returned if the pipeline does not exist
var ErrNoSuchActor = errors.New("no such pipeline")

// NewActorCache creates a ActorCache instance
func NewActorCache(control *control.Client) *ActorCache {
	return &ActorCache{
		control: control,
		cache:   make(map[api.UUID]api.Actor),
	}
}

// ActorCache caches the pipeline definitions
type ActorCache struct {
	control *control.Client
	cache   map[api.UUID]api.Actor
	m       sync.Mutex
}

// Get returns a pipeline info
func (pc *ActorCache) Get(id api.UUID) (api.Actor, error) {
	pc.m.Lock()
	defer pc.m.Unlock()
	if p, ok := pc.cache[id]; ok {
		return p, nil
	}
	rep, err := pc.control.Actor.Query(control.ActorRequest{})
	if err != nil {
		return api.Actor{}, err
	}
	for _, p := range rep.GetActorList() {
		pc.cache[p.ID] = p
	}
	if p, ok := pc.cache[id]; ok {
		return p, nil
	}
	return api.Actor{}, ErrNoSuchActor
}
