// Copyright 2016 Orus.io. All rights reserved.

package sql

import (
	"testing"

	"xbus.io/xbus/storage"
	"xbus.io/xbus/testutils"
	"xbus.io/xbus/testutils/sqldb"
	storagetest "xbus.io/xbus/testutils/storage"
)

func envelopeStorageNGFactoryMaker(tb testing.TB) (func(tb testing.TB) (storage.EnvelopeStorage, func()), func()) {
	tb.Helper()

	testDB := sqldb.GetTestDB(tb)
	if testDB == nil {
		tb.Fatal("Failed to init db")
	}
	m, db := testDB.GetModelDB(20)

	return func(tb testing.TB) (storage.EnvelopeStorage, func()) {
			tb.Helper()

			if _, err := db.Engine.DB().Exec("DELETE FROM envelope_storage"); err != nil {
				tb.Fatal(err)
			}
			if _, err := db.Engine.DB().Exec("DELETE FROM envelope_storage_data"); err != nil {
				tb.Fatal(err)
			}
			return NewEnvelopeStorageNG(m, db, testutils.GetTestLogger(tb)), func() {
			}
		}, func() {
			db.Close()
			testDB.Close()
		}
}

func TestEnvelopeStorageNG(t *testing.T) {
	factory, clean := envelopeStorageNGFactoryMaker(t)
	defer clean()

	storagetest.EnvelopeStorageTests(t, factory, storagetest.EnvelopeStorageTestsOptions{
		SupportUnordered:     false,
		SupportParallelStore: false,
	})
}

func BenchmarkEnvelopeStorageNG(b *testing.B) {
	factory, clean := envelopeStorageNGFactoryMaker(b)
	defer clean()

	storagetest.EnvelopeStorageBench(b, factory)
}
