package model

import (
	"fmt"

	"github.com/rs/zerolog"
	"github.com/slicebit/qb"
)

// QBLogger implements qb.Logger on top of a zerolog.Logger
type QBLogger struct {
	logger   zerolog.Logger
	logFlags qb.LogFlags
}

// Print calls Debug().Msg()
func (l QBLogger) Print(v ...interface{}) {
	l.logger.Debug().Msg(fmt.Sprint(v...))
}

// Printf calls Debug().Msgf()
func (l QBLogger) Printf(f string, v ...interface{}) {
	l.logger.Debug().Msgf(f, v...)
}

// Println calls Debug().Msg()
func (l QBLogger) Println(v ...interface{}) {
	l.logger.Debug().Msg(fmt.Sprintln(v...))
}

// Fatal calls Fatal().Msg()
func (l QBLogger) Fatal(v ...interface{}) {
	l.logger.Fatal().Msg(fmt.Sprint(v...))
}

// Fatalf calls Fatal().Msg()
func (l QBLogger) Fatalf(f string, v ...interface{}) {
	l.logger.Fatal().Msgf(f, v...)
}

// Fatalln calls Fatal().Msg()
func (l QBLogger) Fatalln(v ...interface{}) {
	l.logger.Fatal().Msg(fmt.Sprintln(v...))
}

// Panic calls Panic().Msg()
func (l QBLogger) Panic(v ...interface{}) {
	l.logger.Panic().Msg(fmt.Sprint(v...))
}

// Panicf calls Panic().Msg()
func (l QBLogger) Panicf(f string, v ...interface{}) {
	l.logger.Panic().Msgf(f, v...)
}

// Panicln calls Panic().Msg()
func (l QBLogger) Panicln(v ...interface{}) {
	l.logger.Panic().Msg(fmt.Sprint(v...))
}

// LogFlags returns the current log flags
func (l QBLogger) LogFlags() qb.LogFlags {
	return l.logFlags
}

// SetLogFlags changes the current log flags
func (l *QBLogger) SetLogFlags(flags qb.LogFlags) {
	l.logFlags = flags
}
