package sql

import (
	"testing"

	"xbus.io/xbus/storage"
	"xbus.io/xbus/testutils"
	"xbus.io/xbus/testutils/sqldb"
	storagetest "xbus.io/xbus/testutils/storage"
)

func makePasswordStorageTestFactory(tb testing.TB) (
	func(tb testing.TB) (
		storage.PasswordStorage, func(),
	), func(),
) {
	tb.Helper()

	testDB := sqldb.GetTestDB(tb)
	if testDB == nil {
		return nil, nil
	}
	_, db := testDB.GetModelDB(1)

	return func(tb testing.TB) (storage.PasswordStorage, func()) {
			tb.Helper()

			if _, err := db.Engine.DB().Exec("DELETE FROM passwords"); err != nil {
				tb.Fatal(err)
			}

			return NewPasswordStorage(db, *testutils.GetTestLogger(tb).Zero()), func() {}
		}, func() {
			db.Close()
			testDB.Close()
		}
}

func TestPasswordStorage(t *testing.T) {
	factory, clean := makePasswordStorageTestFactory(t)
	if factory == nil {
		return
	}
	defer clean()
	storagetest.PasswordStorageTests(t, factory)
}
